v.1.0
=====

* Initial verion

0.2.0
=====

* Redesign handlers and signals
* Replace json serializer by pickle
* Add more logs to client and server

0.2.1
=====

Dummy release

0.2.2
=====

* Check required data input in handlers
* Refacroting

0.2.3
=====

* Add abstract handlers

0.2.4
=====

* Cover and log all exceptions in handler's run method in BaseHandler

0.2.5
=====

* Fix BaseResult class
* Add some readme text

0.2.6
=====

* Fix in handler's required data check
* Fix typos

0.2.7
=====

* Bugfix

0.2.8
=====

* Getting result as dict
* Clean up keys, passed to handler
* Resource usage improvements

0.2.9
=====

* Improve BaseResult class

0.2.10
======

* Add protocol version into messages

0.2.11
======

* Bugfix